*It is strongly advised to perform an update of your tentacles after updating OctoBot.*

Changelog for 2.0.3
====================
*Released date : June 12 2019*
### Fixed
- Package data

Changelog for 2.0.2
====================
*Released date : April 19 2019*

- Fixed url typo

Changelog for 2.0.1
====================
*Released date : April 19 2019*

- Added config schema in environment build

Changelog for 2.0.0
====================
*Released date : March 12 2019*

- Updated to web launcher

Changelog for 1.1.1
====================
*Released date : January 19 2019*

- Fix tentacle installation issue

Changelog for 1.1.0
====================
*Released date : January 19 2019*

- Fix restart launcher issue
- Checksum for releases
- Support OctoBot package installation, update and start
- Improve command line interface

Changelog for 1.0.9-a
====================
*Released date : January 17 2019*

- Small fixes

Changelog for 1.0.9
====================
*Released date : January 17 2019*

- Small fixes

Changelog for 1.0.8
====================
*Released date : January 15 2019*

# Features :
    - OctoBot package download and start

Changelog for 1.0.7
====================
*Released date : January 11 2019*

# Features :
    - Launcher latest version
    - MacOS support

Changelog for 1.0.6
====================
*Released date : January 7 2019*

# Bug fixes :
    - Fixed Windows startup issues
